# Velocyto [![Build Status](https://travis-ci.org/velocyto-team/velocyto.py.svg?branch=master)](https://travis-ci.org/velocyto-team/velocyto.py)
This repo contains the source code for `the velocyto.py` library.

For more information consult the [velocyto.py documentation](http://velocyto.org/velocyto.py/index.html).
